pub struct InputRelation {
pub contains: bool,
pub strict_contains: bool,
pub contained: bool,
pub strict_contained: bool,
pub intersect: bool,
pub disjoint: bool,
pub early_exit: bool,
}Expand description
This struct is used to query the specific relationship between two shapes. By default nothing is enabled and no relation are computed.
Fields
contains: boolReturn true if any part on the first shape contains any part of the second shape.
strict_contains: boolReturn true if any parts of the first shape contains all parts of the second shape. The difference between the strict and lose contains are when dealing with multi-shape. Contains would return true if only one point of a multi-poins is contained in the first shape. The strict contains only returns true if all the points of the multi-points are contained in the first shape. It’s also way more expensive to compute.
contained: boolReturn true if any part on the first shape is contained in any part of the second shape.
strict_contained: boolintersect: booldisjoint: boolearly_exit: boolIf set to true the relation algorithm will stop as soon as possible after filling any value.
For example if you are asking if a shape contains, is contained or intersect with another but
don’t really care about which of these happened you can set early_exit to true and the relation
algorithm will be able to exit directly after finding the first intersection for example.
Implementations
Sourceimpl InputRelation
impl InputRelation
pub fn all() -> Self
pub fn any() -> Self
pub fn swap_contains_relation(self) -> Self
pub fn none() -> Self
pub fn to_false(self) -> OutputRelation
pub fn to_true(self) -> OutputRelation
pub fn strip_strict(self) -> Self
pub fn strip_strict_contained(self) -> Self
pub fn strip_disjoint(self) -> Self