pub struct Zolygon<'a> { /* private fields */ }Expand description
A polygon is a closed shape defined by a list of coordinates.
The polygon is represented by a bounding box and a list of coordinates.
The coordinates are stored in a Coords struct, which is a slice of f64 values.
The first and last coordinates must be the same.
Don’t support holes.
Implementations
Sourceimpl<'a> Zolygon<'a>
impl<'a> Zolygon<'a>
pub fn new(bounding_box: &'a BoundingBox, coords: &'a Coords) -> Self
pub fn from_bytes(data: &'a [u8]) -> Self
pub fn write_from_geometry( writer: &mut impl Write, geometry: &Polygon<f64>, ) -> Result<(), Error>
pub fn bounding_box(&self) -> &'a BoundingBox
pub fn coords(&self) -> &'a Coords
pub fn segments(&self) -> impl Iterator<Item = Segment<'a>>
pub fn is_empty(&self) -> bool
pub fn to_geo(&self) -> Polygon<f64>